clc
%--------------------------------------------------------%
%% Calculation of analytical omega
%  The script calculates the analytical value of the void 
%  volume fraction omega. The first calculation is done 
%  with varying triaxility and further on compared to a 
%  constant triaxility. Last the simulated value from 
%  LS-DYNA is plotted for comparisson
%
%  Abbreviations:
%  Void volume fraction = VVF
%
%  Variables:
%  T - Triaxility = Sigma_h/Sigma_eq
%  p - equivalent plastic strain, p_0 - initial , 
%  p_max - end strain 
% 
%%
% Gurson matrix contains triaxility(:,2) and equivalent
% plastic strain(:,1) from simulation:
gursoninput=importdata('gurson.mat'); 
%
% Imports material parameters used in the simulations: 
omega_0=importdata('results/omega_0.txt');
mat(1)=importdata('results/sigma_0.txt');
mat(2)=importdata('results/Q1.txt');
mat(3)=importdata('results/theta1.txt')/mat(2);
mat(4)=importdata('results/Q2.txt');
mat(5)=importdata('results/theta2.txt')/mat(4);
%
%%
% P = ['fitting parameter beta_1' 'fitting 
%       parameter beta_2' 'Initial VVF omega_0']:
n=length(gursoninput(:,1)); P=[1.5 1.0 omega_0];
analyticomega(1)=P(3); matrixstrain=0;

% Loop calculates VVF for each increment of equivialent 
% plastic strain, within each increment the triaxility 
% remains constant:
%
for i=2:n
    T=gursoninput(i-1,2);
    p_max=gursoninput(i,1);
    p0=gursoninput(i-1,1);
    P(3)=analyticomega(i-1);
    [pM,Omega]=gursonincrement(P,T,p0,p_max,mat...
                               ,matrixstrain);
    analyticomega(i)=max(Omega);
    matrixstrain=max(pM);
end
%
%%  
% For comparison the VVF is calcualted with a constant 
% triaxility throughout the plastic strain evolution:
matrixstrain=0; T=mean(gursoninput(:,2));
P=[1.5 1.0 omega_0 0]; p0=min(gursoninput(:,1));
p_max=max(gursoninput(:,1)); 
[p,Omega]=gursonincrement(P,T,p0,p_max,mat,matrixstrain);
%%
%% plotting analytical VVF with varying triaxility
%
figure(1); subplot(2,2,1); plot(gursoninput(:,1),analyticomega)
xlabel('Plastic strain \epsilon^p [mm/mm]')
ylabel('Void volume fraction \omega [vol.%]')
grid on; hold on;
% Adjusting mismatching matrix dimension for plotting
a=length(Omega); strain=linspace(p0,p_max,a);
% plotting into fig(1)
plot(strain,Omega,'--','color','k'); hold on
%
%% Importing simulated results from LS-DYNA
%
lsdynainput=importdata('stresses.mat');
% Extracting VVF evolution
w=lsdynainput(:,5);
% Adjusting mismatching matrix dimension for plotting
a=length(w); strain=linspace(p0,p_max,a);
%
% Plotting into fig(1)
plot(gursoninput(:,1),gursoninput(:,3),'-.','color','r')
%
%% Printing files
if sp=='0';
b=sprintf('Analytical void growth with \nconstant \\sigma^* (Mean value)');
a=sprintf('Simulated void growth by \nLS-DYNA SIMLAB metal model');
%
legend('Analytical void growth with varying \sigma^*',...
    b,a,'location','NorthEastOutside')
end

print(gcf,'-dpdf','void_growth')
movefile('void_growth.pdf','figures/void_growth.pdf')

%% END
delete('gursonincrement.m');
close all
cd(cf)

